Skip to main content
summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'bundles/org.eclipse.compare/plugins/org.eclipse.compare/compare/org/eclipse/compare/internal/TokenComparator.java')
-rw-r--r--bundles/org.eclipse.compare/plugins/org.eclipse.compare/compare/org/eclipse/compare/internal/TokenComparator.java11
1 files changed, 5 insertions, 6 deletions
diff --git a/bundles/org.eclipse.compare/plugins/org.eclipse.compare/compare/org/eclipse/compare/internal/TokenComparator.java b/bundles/org.eclipse.compare/plugins/org.eclipse.compare/compare/org/eclipse/compare/internal/TokenComparator.java
index e1aca48c9..e2ecaf7eb 100644
--- a/bundles/org.eclipse.compare/plugins/org.eclipse.compare/compare/org/eclipse/compare/internal/TokenComparator.java
+++ b/bundles/org.eclipse.compare/plugins/org.eclipse.compare/compare/org/eclipse/compare/internal/TokenComparator.java
@@ -32,7 +32,7 @@ public class TokenComparator implements ITokenComparator {
/**
* Creates a <code>TokenComparator</code> for the given string.
*
* @param string the string that is split into token
*/
public TokenComparator(String text) {
@@ -69,11 +69,11 @@ public class TokenComparator implements ITokenComparator {
/**
* Creates a <code>TokenComparator</code> for the given string.
*
* @param string the string that is split into token
* @param shouldEscape
*/
- public TokenComparator(String s, boolean shouldEscape) {
- this(s);
+ public TokenComparator(String text, boolean shouldEscape) {
+ this(text);
fShouldEscape= shouldEscape;
}
@@ -124,9 +124,8 @@ public class TokenComparator implements ITokenComparator {
return false;
}
- /**
+ /*
* Aborts the comparison if the number of tokens is too large.
- *
* @return <code>true</code> to abort a token comparison
*/
public boolean skipRangeComparison(int length, int max, IRangeComparator other) {
@@ -32,7 +32,7 @@ public class TokenComparator implements ITokenComparator {
* Creates a <code>TokenComparator</code> for the given string.
*
- * @param string the string that is split into token
+ * @param text the string that is split into token
*/
public TokenComparator(String text) {
@@ -69,11 +69,11 @@ public class TokenComparator implements ITokenComparator {
* Creates a <code>TokenComparator</code> for the given string.
*
- * @param string the string that is split into token
+ * @param text the string that is split into token
* @param shouldEscape
*/

Back to the top